@@ -27,6 +27,10 @@ def calculate_ao(df, column_name):
 
 def calculate_smma(df, period, column_name, apply_to):
     """Calculate Smoothed Moving Average"""
+    
+    if df.index.name == 'Date':
+        df.reset_index(inplace=True)
+        
     df_tmp = df[[apply_to]]
     first_val = df_tmp[apply_to].iloc[:period].mean()
     df_tmp = df_tmp.assign(column_name=None)
